"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BufferAvailabilityInfo = void 0;
/**
 * Implementation of an `AvailabilityInfo` that is backed by
 * a Buffer.
 *
 * @internal
 */
class BufferAvailabilityInfo {
    constructor(buffer, length) {
        this._buffer = buffer;
        this._length = length;
    }
    /** {@inheritDoc AvailabilityInfo.length} */
    get length() {
        return this._length;
    }
    /** {@inheritDoc AvailabilityInfo.isAvailable} */
    isAvailable(index) {
        if (index < 0 || index >= this.length) {
            throw new RangeError(`Index must be in [0,${this.length}), but is ${index}`);
        }
        const byteIndex = index >> 3;
        const bitIndex = index % 8;
        const b = this._buffer[byteIndex];
        const bit = 1 << bitIndex;
        const result = (b & bit) != 0;
        return result;
    }
}
exports.BufferAvailabilityInfo = BufferAvailabilityInfo;
//# sourceMappingURL=BufferAvailabilityInfo.js.map